View source: R/ggparallel_specific_utils.R
| fct_infreq | R Documentation |
Reorders the levels of a factor by their frequency, in descending order.
fct_infreq(x)
x |
A factor or an object coerced to a factor. |
A factor with levels ordered by descending frequency.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.