View source: R/ggparallel_specific_utils.R
| is_crossing | R Documentation |
Given the positions of two edges on the left and right axes, decides if they intersect in a parallel coordinates setup.
is_crossing(l1, r1, l2, r2)
l1 |
Numeric position of the first edge on the left axis. |
r1 |
Numeric position of the first edge on the right axis. |
l2 |
Numeric position of the second edge on the left axis. |
r2 |
Numeric position of the second edge on the right axis. |
A logical value. TRUE if they cross, FALSE otherwise.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.