View source: R/ggparallel_specific_utils.R
| fct_relevel_base | R Documentation |
Reorder the levels of a factor by moving specified levels to a new position.
fct_relevel_base(x, ..., after = 0)
x |
A factor to be releveled. |
... |
Levels to move in the factor. |
after |
A numeric scalar specifying the position after which the moved
levels should be placed. Use |
A factor with the specified levels moved to the chosen position.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.